<template>
  <div>
    <el-dialog
      :close-on-click-modal="false"
      width="50%"
      :title="titles + '物资分类信息'"
      :visible.sync="showFormDias"
      :before-close="handleClose"
    >
      <el-form
        ref="formInfo"
        :rules="rules"
        :model="params"
        label-width="100px"
      >
        <!-- <el-collapse accordion v-model="activeCollapse" class="form-collapse">
          <el-collapse-item name="1"> -->
        <template slot="title">
          <span class="collapse-title">
            <i class="collapse-title-icon el-icon-info" />
            基本信息
          </span>
        </template>
        <el-row>
          <!-- typeName -->
          <el-col :span="8">
            <el-form-item prop="name" label="分类名称">
              <el-input
                v-model="params.name"
                maxlength="30"
                placeholder="请输入分类名称"
              />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item prop="code" label="分类编码">
              <el-input
                v-model="params.code"
                maxlength="30"
                placeholder="请输入分类编码"
              />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item prop="parentId" label="上级分类">
              <!-- <ebs-tree-select
                v-model="params.parentId"
                :props="treeSelectProps"
                :options="treeData"
                :disabled="false"
              /> -->
              <el-select disabled v-model="params.parentId" placeholder="请选择上级分类">
                <el-option
                  v-for="(item,index) in optionsList"
                  :key="index"
                  :label="item.name"
                  :value="item.id">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="备注" prop="memo">
          <el-input
            v-model="params.memo"
            type="textarea"
            :autosize="{minRows: 5}"
            maxlength="200"
            show-word-limit
            placeholder="请输入备注内容"
          />
        </el-form-item>
        <!-- </el-collapse-item>
        </el-collapse> -->
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="handleSave">保 存</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import utils from '@/hotent-ui-util.js'
import classManage from '@/api/manager/material/materialInfoManage.js'
import ebsTreeSelect from '@/views/Manage/components/SelectTree.vue'
import PY from '@/views/Manage/components/PY.js'

export default {
  name: 'ClassFormDialog',
  components: {
    ebsTreeSelect
  },
  props: {
    showFormDias: {
      type: Boolean,
      default: false
    },
    titles: {
      type: String,
      default: ''
    },
    treeNode: {
      type: Object,
      default: null
    },
    pOptions: {
      type: Array,
      default: []
    }
  },
  data() {
    return {
      params: {
        // id: null,
        name: '',
        code: '',
        parentId: '',
        memo: ''
      },
      treeData: [
        {
          code: '0',
          id: '0',
          name: '物资分类信息',
          parentId: null,
          children: []
        }
      ],
      treeSelectProps: {
        value: 'id', // ID字段名
        label: 'name', // 显示名称
        children: 'children' // 子级字段名
      },
      activeCollapse: '1',
      rules: {
        name: [
          {
            required: true,
            message: '请输入分类名称',
            trigger: 'blur'
          }
        ]
      },
      optionsList: []
    }
  },
  watch: {
    treeNode: function(newVal, oldVal) {
      console.log('watch===================', newVal)
      this.params = newVal
    }
  },
  created() {
    if (this.titles === '修改') {
      classManage.getClassByID(this.pOptions[0].id, (res => {
        console.log(res)
        this.params = res
        this.optionsList = [{id: res.parentId, name: res.parentName}]
      }))
    } else if (this.titles === '新增') {
      this.optionsList = this.pOptions
      this.params.parentId = this.optionsList[0].id
    }

  },
  mounted() {
    // this.getTree()
  },
  // destroyed() {
  // 	this.params = {
  // 			id: null,
  // 	  typeName: '',
  // 	  code: '',
  // 	  parentId: null
  // 	}
  // },
  methods: {
    getTree() {
      classManage.loadAllClass({}, res => {
        this.treeData[0].children = res
        // this.$set(this.treeData)
        if (this.treeNode) {
          this.params = this.treeNode
          console.log('params====mounted============', this.treeNode)
        }
      })
    },
    changeType() {
      this.$forceUpdate()
    },
    handleClose() {
      this.params = {
        id: null,
        name: '',
        code: '',
        parentId: null
      }
      this.$refs.formInfo.clearValidate()
      this.$emit('closeFormDiaos')
      this.$emit('refList')
    },
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (!this.params.id) {
            method = classManage.addClass
            if (this.params.code == null || this.params.code === '') {
              this.params.code = PY.getCamelChars(this.params.name)
            }
          }
          if (this.params.id) {
            // 修改
            method = classManage.editClass
          }
          // 父分类是物资分类时parentId
          if (this.params.parentId === 0) {
            this.params.parentId = null
          }
          console.log(method)
          method(this.params, response => {
            if (response.state) {
              this.$notify({
                type: 'success',
                message: this.titles + '成功',
                duration: 2000
              })
              this.$emit('closeFormDiaos')
              this.$emit('refList')
            } else {
              this.$message.warning(response.message)
            }
          })
        } else {
          return false
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.company-type ::v-deep .el-checkbox-group {
  height: initial !important;
}
</style>
